<!--
 * @Date: 2023-01-07 22:59:34
 * @LastEditors: ThetisEliza wxf199601@gmail.com
 * @LastEditTime: 2023-01-10 18:10:35
 * @FilePath: /outlier/README.md
-->
# OUTLIER

## Instruction

This is a simple chat-room for you to communicate with others


## Development log

11.16 
- initialize the project

XXX
- where was my development logs ? 

12.01 
- add a simple encryption method
- refactor the client

12.05
- add log system


12.27
- add active sync feature
- add rotatating

12.28
- I found something really bothering, with the project getting larger, the cost of designing increases exponentially
  
1.10
- I finished all the basic functions in both server and client
- Finished the Decorator Structure to register bussiness functions on both server and client
- Some Efforts are still required to make it cleaner and more beautiful
